import { ScalarApiButton } from './ScalarApiButton';
/**
 * Display the path of an operation.
 */
export function OpenAPIPath(props) {
    var data = props.data, context = props.context;
    var method = data.method, path = data.path;
    var specUrl = context.specUrl;
    return (<div className="openapi-path">
            <div className={"openapi-method openapi-method-".concat(method)}>{method}</div>
            <div className="openapi-path-title" data-deprecated={data.operation.deprecated}>
                <p>{formatPath(path)}</p>
            </div>
            {data['x-hideTryItPanel'] || data.operation['x-hideTryItPanel'] ? null : (<ScalarApiButton method={method} path={path} specUrl={specUrl}/>)}
        </div>);
}
// Format the path to highlight placeholders
function formatPath(path) {
    // Matches placeholders like {id}, {userId}, etc.
    var regex = /\{(\w+)\}/g;
    var parts = [];
    var lastIndex = 0;
    // Replace placeholders with <em> tags
    path.replace(regex, function (match, key, offset) {
        parts.push(path.slice(lastIndex, offset));
        parts.push(<em key={key}>{"{".concat(key, "}")}</em>);
        lastIndex = offset + match.length;
        return match;
    });
    // Push remaining text after the last placeholder
    parts.push(path.slice(lastIndex));
    // Join parts with separators wrapped in <span>
    var formattedPath = parts.reduce(function (acc, part, index) {
        if (typeof part === 'string' && index > 0 && part === '/') {
            acc.push(<span className="openapi-path-separator" key={"sep-".concat(index)}>
                        /
                    </span>);
        }
        acc.push(part);
        return acc;
    }, []);
    return <span>{formattedPath}</span>;
}
