/**
 * Display the schema name row.
 * It includes the property name, type, required and deprecated status.
 */
export function OpenAPISchemaName(props) {
    var schema = props.schema, type = props.type, propertyName = props.propertyName, required = props.required;
    var additionalItems = schema && getAdditionalItems(schema);
    return (<div className="openapi-schema-name">
            {propertyName ? (<span data-deprecated={schema === null || schema === void 0 ? void 0 : schema.deprecated} className="openapi-schema-propertyname">
                    {propertyName}
                </span>) : null}
            <span>
                {type ? <span className="openapi-schema-type">{type}</span> : null}
                {additionalItems ? (<span className="openapi-schema-type">{additionalItems}</span>) : null}
            </span>
            {required ? <span className="openapi-schema-required">required</span> : null}
            {(schema === null || schema === void 0 ? void 0 : schema.deprecated) ? <span className="openapi-deprecated">Deprecated</span> : null}
        </div>);
}
function getAdditionalItems(schema) {
    var additionalItems = '';
    if (schema.minimum || schema.minLength) {
        additionalItems += " \u00B7 min: ".concat(schema.minimum || schema.minLength);
    }
    if (schema.maximum || schema.maxLength) {
        additionalItems += " \u00B7 max: ".concat(schema.maximum || schema.maxLength);
    }
    // If the schema has a default value, we display it
    if (typeof schema.default !== 'undefined') {
        additionalItems += " \u00B7 default: ".concat(schema.default);
    }
    if (schema.nullable) {
        additionalItems = ' | nullable';
    }
    return additionalItems;
}
