'use client';
import { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { Tab, TabList, TabPanel, Tabs } from 'react-aria-components';
import { useIntersectionObserver } from 'usehooks-ts';
import { Markdown } from './Markdown';
import { useSyncedTabsGlobalState } from './useSyncedTabsGlobalState';
var OpenAPITabsContext = createContext(null);
function useOpenAPITabsContext() {
    var context = useContext(OpenAPITabsContext);
    if (!context) {
        throw new Error('OpenAPITabsContext is missing');
    }
    return context;
}
/**
 * The OpenAPI Tabs wrapper component.
 */
export function OpenAPITabs(props) {
    var children = props.children, items = props.items, stateKey = props.stateKey;
    var _a = useIntersectionObserver({
        threshold: 0.1,
        rootMargin: '200px',
    }), ref = _a[0], isIntersectionVisible = _a[1];
    var isVisible = stateKey ? isIntersectionVisible : true;
    var defaultTab = items[0];
    var _b = useSyncedTabsGlobalState(), syncedTabs = _b[0], setSyncedTabs = _b[1];
    var _c = useState(function () {
        var _a, _b, _c;
        if (isVisible && stateKey && syncedTabs && syncedTabs.has(stateKey)) {
            var tabFromState = syncedTabs.get(stateKey);
            return (_a = tabFromState === null || tabFromState === void 0 ? void 0 : tabFromState.key) !== null && _a !== void 0 ? _a : (_b = items[0]) === null || _b === void 0 ? void 0 : _b.key;
        }
        return (_c = items[0]) === null || _c === void 0 ? void 0 : _c.key;
    }), selectedTabKey = _c[0], setSelectedTabKey = _c[1];
    var _d = useState(defaultTab), selectedTab = _d[0], setSelectedTab = _d[1];
    var handleSelectionChange = function (key) {
        setSelectedTabKey(key);
        if (stateKey) {
            var tab_1 = items.find(function (item) { return item.key === key; });
            if (!tab_1) {
                return;
            }
            setSyncedTabs(function (state) {
                var newState = new Map(state);
                newState.set(stateKey, tab_1);
                return newState;
            });
        }
    };
    useEffect(function () {
        if (isVisible && stateKey && syncedTabs && syncedTabs.has(stateKey)) {
            var tabFromState_1 = syncedTabs.get(stateKey);
            if (!items.some(function (item) { return item.key === (tabFromState_1 === null || tabFromState_1 === void 0 ? void 0 : tabFromState_1.key); })) {
                return setSelectedTab(defaultTab);
            }
            if (tabFromState_1 && (tabFromState_1 === null || tabFromState_1 === void 0 ? void 0 : tabFromState_1.key) !== (selectedTab === null || selectedTab === void 0 ? void 0 : selectedTab.key)) {
                var tabFromItems = items.find(function (item) { return item.key === tabFromState_1.key; });
                if (!tabFromItems) {
                    return;
                }
                setSelectedTab(tabFromItems);
            }
        }
    }, [isVisible, stateKey, syncedTabs, selectedTabKey]);
    var contextValue = useMemo(function () { return ({ items: items, selectedTab: selectedTab }); }, [items, selectedTab]);
    return (<OpenAPITabsContext.Provider value={contextValue}>
            <Tabs ref={ref} className="openapi-tabs" onSelectionChange={handleSelectionChange} selectedKey={selectedTab === null || selectedTab === void 0 ? void 0 : selectedTab.key}>
                {children}
            </Tabs>
        </OpenAPITabsContext.Provider>);
}
/**
 * The OpenAPI Tabs list component.
 * This component should be used as a child of the OpenAPITabs component.
 * It renders the list of tabs.
 */
export function OpenAPITabsList() {
    var items = useOpenAPITabsContext().items;
    return (<TabList className="openapi-tabs-list">
            {items.map(function (tab) { return (<Tab style={function (_a) {
                var isFocusVisible = _a.isFocusVisible;
                return ({
                    outline: isFocusVisible
                        ? '2px solid rgb(var(--primary-color-500)/0.4)'
                        : 'none',
                });
            }} className="openapi-tabs-tab" key={"Tab-".concat(tab.key)} id={tab.key}>
                    {tab.label}
                </Tab>); })}
        </TabList>);
}
/**
 * The OpenAPI Tabs panels component.
 * This component should be used as a child of the OpenAPITabs component.
 * It renders the content of the selected tab.
 */
export function OpenAPITabsPanels() {
    var selectedTab = useOpenAPITabsContext().selectedTab;
    if (!selectedTab) {
        return null;
    }
    return (<TabPanel key={"TabPanel-".concat(selectedTab.key)} id={selectedTab.key.toString()} className="openapi-tabs-panel">
            {selectedTab.body}
            {selectedTab.description ? (<Markdown source={selectedTab.description} className="openapi-tabs-footer"/>) : null}
        </TabPanel>);
}
